import * as commonjsHelpers from "_commonjsHelpers.js";

var input = async function () {
	// TODO
};

export default /*@__PURE__*/commonjsHelpers.getDefaultExportFromCjs(input);
export { input as __moduleExports };
